@@ -485,6 +485,7 @@ class ScatteringField(
     @property
     def x(self) -> complex:
         """Product of :attr:`~.k_f` and :attr:`~.R_0`
+        :math:`\\hat{x}=k_f R_0`
         """
         return self._x.value
 
@@ -494,6 +495,7 @@ class ScatteringField(
     @property
     def x_v(self) -> complex:
         """Product of :attr:`~.k_v` and :attr:`~.R_0`
+        :math:`x_v=k_v R_0`
         """
         return self._x_v.value
 
@@ -502,7 +504,8 @@ class ScatteringField(
 
     @property
     def x_hat(self) -> complex:
-        """Product of :attr:`~.k_f` and :attr:`~.R_0`
+        """Product of :attr:`~.k_s` and :attr:`~.R_0`
+        :math:`\\hat{x}=k_s R_0`
         """
         return self._x_hat.value
 
@@ -511,7 +514,8 @@ class ScatteringField(
 
     @property
     def x_hat_v(self) -> complex:
-        """Product of :attr:`~.k_v` and :attr:`~.R_0`
+        """Product of :attr:`~.k_vs` and :attr:`~.R_0`
+        :math:`\\hat{x}_v=\\hat{k}_s R_0`
         """
         return self._x_hat_v.value
 
