@@ -68,7 +68,7 @@ class TestARFBase(TestBase):
 
         self.assertRaises(
             WrongWaveTypeError,
-            self.cls.acoustic_radiation_force,
+            self.cls.compute_arf,
         )
     # ------------------
 
