@@ -14,7 +14,7 @@ class HelperARF:
 
     def test_arf(self) -> None:
         self.do_testing(
-            self.compute_arf, self.cls.acoustic_radiation_force,
+            self.compute_arf, self.cls.compute_arf,
             threshold=self._threshold,
             zero=1e-30,
         )
@@ -42,8 +42,8 @@ class HelperCompareARF:
 
     def test_comparison_arf(self):
         self.do_testing(
-            self.cls.acoustic_radiation_force,
-            self.compare_cls.acoustic_radiation_force,
+            self.cls.compute_arf,
+            self.compare_cls.compute_arf,
             threshold=self.arf_compare_threshold,
             zero=1e-30,
         )
